@@ -3,6 +3,7 @@ from .const import VERSION
 from .gql_handler_async import *
 from datetime import datetime
 from asyncio import sleep
+from .exeption_classes import LoginError
 
 class PyXploraApi:
     def __init__(self, countrycode: str, phoneNumber: str, password: str, userLang: str, timeZone: str, watchNo: int=0) -> None:
@@ -80,7 +81,7 @@ class PyXploraApi:
                 self.watch = token['user']['children'][self.watch_no]['ward']
                 self.user = token['user']
                 return
-        raise Exception("Fail")
+        raise LoginError("Login to Xplora® API failed. Check your input!")
 
     def version(self) -> str:
         return VERSION
